@@ -102,9 +102,10 @@ def read_fasta(stream):
 
 EntryBin = namedtuple('Entry', 'header sequence bits')
 
-def tofastab(fasta, stream):
+def tofastab(fasta, stream, force_upper = True):
     """
     Save a FASTA 'Entry' into a binary stream.
+    'force_upper' will force the DNA sequence to be upper-case when True (which is the default).
 
     The format is as follows:
 
@@ -122,9 +123,11 @@ def tofastab(fasta, stream):
 
     if len(header) > 256**2:
         raise ValueError("Header is too long")
-    
-    sequence = bytes(fasta.sequence)
 
+    if force_upper:
+        sequence = bytes(fasta.sequence.upper())
+    else:
+        sequence = bytes(fasta.sequence)
     vec = PackedDNABytes(sequence)
 
     stream.write(struct.pack('<QH%is%ss' %(len(header), str(len(vec))),
